@@ -3,17 +3,20 @@ package XTM::XML::MemoryBuilder;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 use base qw(XML::SAX::Base);
+use XML::SAX::Exception;
+@XML::SAX::Exception::XTMError::ISA = ('XML::SAX::Exception');
 
 require Exporter;
 require AutoLoader;
 
-
 use XTM;
 use XTM::PSI;
 use XTM::Log ('elog');
-use XTM::XML::ParseError;
 use XTM::Namespaces;
 
+$VERSION = '0.06';
+
+
 my $tmns    = $XTM::Namespaces::topicmap_ns;
 my $xlinkns = $XTM::Namespaces::xlink_ns;
 
@@ -201,7 +204,7 @@ my %handlers =
       push @{$handler->{parent}}, new XTM::instanceOf ();
 
     },
-#                <!ELEMENT instanceOf  ( topicRef | subjectIndicatorRef ) > 
+#                <!ELEMENT instanceOf  ( topicRef | subjectIndicatorRef ) >
     'allowed_elements' => [ qw(topicRef subjectIndicatorRef) ],
     'end' =>
     sub {
@@ -209,9 +212,9 @@ my %handlers =
       my $element = shift;
 
       my $i = pop @{$handler->{parent}};
-      die "XTM::XML::MemoryBuilder, conformance error in '$element->{Name}': see XTM standard, 3.4.1\n" 
+      die "XTM::XML::MemoryBuilder, conformance error in '$element->{Name}': see XTM standard, 3.4.1\n"
 	unless $i->topicRef_s + $i->subjectIndicatorRef_s == 1;
-      
+
       $i->add_reference ($i->topicRef_s, $i->subjectIndicatorRef_s);  $i->undefine (qw (topicRefs subjectIndicatorRefs));
       $handler->{parent}->[-1]->add__s ($i);
     },
@@ -243,7 +246,7 @@ my %handlers =
       die "XTM::XML::MemoryBuilder, conformance error in '$element->{Name}': see XTM standard, 3.6.2\n"  if $s->resourceRef_s > 1;
       $s->add_resourceRef ($s->resourceRef_s);  $s->undefine (qw (resourceRefs));
 
-      $s->add_references ($s->topicRef_s, $s->subjectIndicatorRef_s);  $s->undefine (qw (topicRefs subjectIndicatorRefs));
+      $s->add_reference_s ($s->topicRef_s, $s->subjectIndicatorRef_s);  $s->undefine (qw (topicRefs subjectIndicatorRefs));
       $handler->{parent}->[-1]->add__s ($s);
     },
    },
@@ -396,7 +399,7 @@ my %handlers =
       $handler->xtm_error ( "XTM::XML::MemoryBuilder, conformance error in '$element->{Name}': see XTM standard, 3.7.5\n" )
 	if $ps->topicRef_s + $ps->subjectIndicatorRef_s == 0;
 
-      $ps->add_references ($ps->topicRef_s, $ps->subjectIndicatorRef_s);  $ps->undefine (qw (topicRefs subjectIndicatorRefs));
+      $ps->add_reference_s ($ps->topicRef_s, $ps->subjectIndicatorRef_s);  $ps->undefine (qw (topicRefs subjectIndicatorRefs));
       $handler->{parent}->[-1]->add__s ($ps);
     },
    },
@@ -438,10 +441,10 @@ my %handlers =
 	$a->add__s (new XTM::scope ( references =>  [ new XTM::topicRef (href => $XTM::PSI::xtm{universal_scope}) ]));
       }
       $a->add_scope ($a->scope_s);  $a->undefine (qw (scopes));
-      
+
       $handler->xtm_error ( "XTM::XML::MemoryBuilder, conformance error in '$element->{Name}': see XTM standard, 3.8.1\n" )
 	if $a->member_s == 0;
-      
+
       $handler->{parent}->[-1]->add ($a);
     },
    },
@@ -549,7 +552,7 @@ my %handlers =
       $handler->xtm_error ( "XTM::XML::MemoryBuilder, conformance error in '$element->{Name}': see XTM standard, 3.9.1\n" )
 	unless $o->resourceRef_s + $o->resourceData_s == 1;
       $o->add_resource ($o->resourceRef_s, $o->resourceData_s);  $o->undefine (qw (resourceRefs resourceDatas));
-      
+
       $handler->{parent}->[-1]->add__s ($o);
     },
    },
@@ -711,13 +714,11 @@ sub end_element {
 
 
 sub xtm_error {
-  my $self = shift;
+  my $self    = shift;
   my $message = shift;
 
-  my $exception = new XTM::XML::ParseError ($message.
-					    " [Ln: " . $self->{LineNumber} . ", Col: " . $self->{ColumnNumber} . "]");
-  $self->fatal_error($exception);
-  $exception->throw;
+  throw XML::SAX::Exception::XTMError (Message => $message.
+				       " [Ln: " . $self->{LineNumber} . ", Col: " . $self->{ColumnNumber} . "]");
 }
 
 =pod
@@ -725,9 +726,10 @@ sub xtm_error {
 =head1 AUTHOR INFORMATION
 
 Copyright 2002, Robert Barta <rho@telecoma.net>, All rights reserved.
- 
+
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
+http://www.perl.com/perl/misc/Artistic.html
 
 =cut
 
